@@ -12,28 +12,30 @@ make_base = function(heightmap,basedepth=0,basecolor="grey20",zscale=1, soil = F
                      soil_freq = 0.1, soil_levels = 8, soil_color1 = "black", soil_color2 = "black",
                      soil_gradient = 0, gradient_darken = 1) {
   heightmap = heightmap/zscale
-  edge_vals = unique(c(heightmap[1,], heightmap[,1],heightmap[nrow(heightmap),],heightmap[,ncol(heightmap)]))
+  nc = ncol(heightmap)
+  nr = nrow(heightmap)
+  edge_vals = unique(c(heightmap[1,], heightmap[,1],heightmap[nr,],heightmap[,nc]))
   if(length(edge_vals) == 1 && all(!is.na(edge_vals))) {
     heightlist = list()
-    nc = ncol(heightmap)
-    nr = nrow(heightmap)
-    heightlist[[1]] = matrix(c(1, nr, nr, basedepth,basedepth,basedepth,-1, -nc,-1),3,3)
-    heightlist[[2]] = matrix(c(1, nr,1,basedepth,basedepth,basedepth, -nc, -nc,-1),3,3)
-    heightlist[[3]] = matrix(c(1, nr,1, basedepth,basedepth,edge_vals,-1,-1,-1),3,3)
-    heightlist[[4]] = matrix(c( nr, nr,1,basedepth,edge_vals,edge_vals,-1,-1,-1),3,3)
-    heightlist[[5]] = matrix(c(1, nr, 1, edge_vals,basedepth,basedepth, -nc, -nc, -nc),3,3)
-    heightlist[[6]] = matrix(c( 1, nr, nr,edge_vals,edge_vals,basedepth, -nc, -nc, -nc),3,3)
-    heightlist[[7]] = matrix(c(nr, nr, nr, basedepth,basedepth,edge_vals,-1,-nc,-1),3,3)
-    heightlist[[8]] = matrix(c(nr, nr, nr,basedepth,edge_vals,edge_vals,-nc,-nc,-1),3,3)
-    heightlist[[9]] = matrix( c(1,1,1, edge_vals,basedepth,basedepth, -1, -nc, -1),3,3)
-    heightlist[[10]] = matrix(c(1,1,1, edge_vals,edge_vals,basedepth, -1, -nc, -nc),3,3)
+    heightlist[[1]] = matrix(c(1, nr, nr, basedepth, basedepth, basedepth, 1,  nc, 1),3,3)
+    heightlist[[2]] = matrix(c(1, nr,  1, basedepth, basedepth, basedepth, nc, nc, 1),3,3)
+    heightlist[[3]] = matrix(c(1, nr,1, basedepth,basedepth,edge_vals,1,1,1),3,3)
+    heightlist[[4]] = matrix(c( nr, nr,1,basedepth,edge_vals,edge_vals,1,1,1),3,3)
+    heightlist[[5]] = matrix(c(1, nr, 1, edge_vals,basedepth,basedepth, nc, nc, nc),3,3)
+    heightlist[[6]] = matrix(c( 1, nr, nr,edge_vals,edge_vals,basedepth, nc, nc, nc),3,3)
+    heightlist[[7]] = matrix(c(nr, nr, nr, basedepth,basedepth,edge_vals,1, nc,1),3,3)
+    heightlist[[8]] = matrix(c(nr, nr, nr,basedepth,edge_vals,edge_vals, nc, nc,1),3,3)
+    heightlist[[9]] = matrix( c(1,1,1, edge_vals,basedepth,basedepth, 1, nc, 1),3,3)
+    heightlist[[10]] = matrix(c(1,1,1, edge_vals,edge_vals,basedepth, 1, nc, nc),3,3)
     fullsides = do.call(rbind,heightlist)
-    fullsides[,1] = fullsides[,1] - nrow(heightmap)/2
-    fullsides[,3] = -fullsides[,3] - ncol(heightmap)/2
-    fullsides = fullsides[nrow(fullsides):1,]
+    fullsides = fullsides[rev(seq_len(nrow(fullsides))),]
+    fullsides[,1] = fullsides[,1] - 1
+    fullsides[,3] = fullsides[,3] - 1
+    fullsides[,1] = fullsides[,1] - (nr-1)/2
+    fullsides[,3] = fullsides[,3] - (nc-1)/2
     rgl::triangles3d(fullsides, 
                      texture = NULL,
-                     lit=FALSE,color=basecolor,front="filled",back="culled",tag = "base")
+                     lit=FALSE,color=basecolor,front="filled",back="cull",tag = "base")
   } else if(all(!is.na(heightmap))) {
     na_matrix = is.na(heightmap)
     baselist = make_base_cpp(heightmap, na_matrix, basedepth)
@@ -41,8 +43,8 @@ make_base = function(heightmap,basedepth=0,basecolor="grey20",zscale=1, soil = F
     edge_heights = as.vector(t(cbind(baselist$edge_heights,baselist$edge_heights,baselist$edge_heights)))
     direction_vec = as.vector(t(cbind(baselist$is_horizontal,baselist$is_horizontal,baselist$is_horizontal)))
     
-    heightlist[[length(heightlist)+1]] = matrix(c(1,nrow(heightmap),nrow(heightmap), basedepth,basedepth,basedepth,-1,-ncol(heightmap),-1),3,3)
-    heightlist[[length(heightlist)+1]] = matrix(c(1,nrow(heightmap),1,basedepth,basedepth,basedepth,-ncol(heightmap),-ncol(heightmap),-1),3,3)
+    heightlist[[length(heightlist)+1]] = matrix(c(1,nr,nr, basedepth,basedepth,basedepth,-1,-nc,-1),3,3)
+    heightlist[[length(heightlist)+1]] = matrix(c(1,nr,1,basedepth,basedepth,basedepth,-nc,-nc,-1),3,3)
     direction_vec = c(direction_vec, rep(FALSE,6))
     direction_vec = rev(direction_vec)
 
@@ -50,9 +52,12 @@ make_base = function(heightmap,basedepth=0,basecolor="grey20",zscale=1, soil = F
     edge_heights = rev(edge_heights)
 
     fullsides = do.call(rbind,heightlist)
-    fullsides[,1] = fullsides[,1] - nrow(heightmap)/2
-    fullsides[,3] = -fullsides[,3] - ncol(heightmap)/2
-    fullsides = fullsides[nrow(fullsides):1,]
+    fullsides[,3] = -fullsides[,3]
+    fullsides[,1] = fullsides[,1] - 1
+    fullsides[,3] = fullsides[,3] - 1
+    fullsides[,1] = fullsides[,1] - (nr-1)/2
+    fullsides[,3] = fullsides[,3] - (nc-1)/2
+    fullsides = fullsides[rev(seq_len(nrow(fullsides))),]
 
     if(soil) {
       horizontal_sides = fullsides[!direction_vec,]
@@ -68,7 +73,7 @@ make_base = function(heightmap,basedepth=0,basecolor="grey20",zscale=1, soil = F
       min_hside_y = min(horizontal_sides[,2],na.rm=TRUE)
       max_hside_y = max(horizontal_sides[,2],na.rm=TRUE)
       
-      horizontal_texcoords_x = (horizontal_sides[,1] + nrow(heightmap)/2-1)/(nrow(heightmap)-1)
+      horizontal_texcoords_x = (horizontal_sides[,1] + nr/2-1)/(nr-1)
       # horizontal_texcoords_y = (horizontal_sides[,2]-min_hside_y)/(max_hside_y-min_hside_y)
       
       horizontal_texcoords_y = rep(0,length(horizontal_sides[,2]))
@@ -82,7 +87,7 @@ make_base = function(heightmap,basedepth=0,basecolor="grey20",zscale=1, soil = F
       min_vside_y = min(vertical_sides[,2],na.rm=TRUE)
       max_vside_y = max(vertical_sides[,2],na.rm=TRUE)
       
-      vertical_texcoords_x = (vertical_sides[,3] + ncol(heightmap)/2-1)/(ncol(heightmap)-1)
+      vertical_texcoords_x = (vertical_sides[,3] + nc/2-1)/(nc-1)
       # vertical_texcoords_y = (vertical_sides[,2]-min_vside_y)/(max_vside_y-min_vside_y)
       vertical_texcoords_y = rep(0,length(vertical_sides[,2]))
       # vertical_texcoords_y[vertical_sides[,2] == basedepth] = vertical_heights[vertical_sides[,2] == basedepth]/(max_vside_y-min_vside_y)
@@ -109,12 +114,16 @@ make_base = function(heightmap,basedepth=0,basecolor="grey20",zscale=1, soil = F
     direction_vec = rev(as.vector(t(cbind(baselist$is_horizontal,baselist$is_horizontal,baselist$is_horizontal))))
     
     fullsides = do.call(rbind,heightlist)
-    fullsides[,1] = fullsides[,1] - nrow(heightmap)/2
-    fullsides[,3] = -fullsides[,3] - ncol(heightmap)/2
-    fullsides = fullsides[nrow(fullsides):1,]
-    basemat = matrix(basedepth,nrow(heightmap),ncol(heightmap))
+    fullsides[,3] = -fullsides[,3]
+    fullsides[,1] = fullsides[,1] - 1
+    fullsides[,3] = fullsides[,3] - 1
+    fullsides[,1] = fullsides[,1] - (nr-1)/2
+    fullsides[,3] = fullsides[,3] - (nc-1)/2
+    fullsides = fullsides[rev(seq_len(nrow(fullsides))),]
+    
+    basemat = matrix(basedepth,nr,nc)
     basemat[is.na(heightmap)] = NA
-    normalmat = matrix(0,nrow(heightmap),ncol(heightmap))
+    normalmat = matrix(0,nr,nc)
     xznormals = fliplr(heightmap)
     ynormals = fliplr(heightmap)
     xznormals[!is.na(xznormals)] = 0
@@ -134,7 +143,7 @@ make_base = function(heightmap,basedepth=0,basecolor="grey20",zscale=1, soil = F
       min_hside_y = min(horizontal_sides[,2],na.rm=TRUE)
       max_hside_y = max(horizontal_sides[,2],na.rm=TRUE)
       
-      horizontal_texcoords_x = (horizontal_sides[,1] + nrow(heightmap)/2-1)/(nrow(heightmap)-1)
+      horizontal_texcoords_x = (horizontal_sides[,1] + nr/2-1)/(nr-1)
       # horizontal_texcoords_y = (horizontal_sides[,2]-min_hside_y)/(max_hside_y-min_hside_y)
       
       horizontal_texcoords_y = rep(0,length(horizontal_sides[,2]))
@@ -147,7 +156,7 @@ make_base = function(heightmap,basedepth=0,basecolor="grey20",zscale=1, soil = F
       min_vside_y = min(vertical_sides[,2],na.rm=TRUE)
       max_vside_y = max(vertical_sides[,2],na.rm=TRUE)
       
-      vertical_texcoords_x = (vertical_sides[,3] + ncol(heightmap)/2-1)/(ncol(heightmap)-1)
+      vertical_texcoords_x = (vertical_sides[,3] + nc/2-1)/(nc-1)
       # vertical_texcoords_y = (vertical_sides[,2]-min_vside_y)/(max_vside_y-min_vside_y)
       vertical_texcoords_y = rep(0,length(vertical_sides[,2]))
       vertical_texcoords_y[vertical_sides[,2] == basedepth] = vertical_heights[vertical_sides[,2] == basedepth]/(max_vside_y-min_vside_y)
@@ -164,14 +173,25 @@ make_base = function(heightmap,basedepth=0,basecolor="grey20",zscale=1, soil = F
     } else {
       rgl::triangles3d(fullsides,
                        texture = NULL,
-                       lit=FALSE,color=basecolor,front="filled",back="filled",tag = "base")
+                       lit=FALSE,color=basecolor,front="filled",back="cull",tag = "base")
     }
-    rgl::surface3d(x=1:nrow(basemat)-nrow(basemat)/2,
-                   z=1:ncol(basemat)-ncol(basemat)/2,
-                   y=basemat,
-                   color=basecolor, 
-                   lit=FALSE,back="filled",front="filled",tag = "basebottom",
-                   normal_x = xznormals, normal_z = xznormals, normal_y = ynormals)
+    basemat = matrix(basedepth,nr,nc)
+    basemat[is.na(heightmap)] = NA
+    ray_base = generate_surface(basemat, zscale = 1)
+    ray_base$inds = ray_base$inds[3:1,]
+    
+    rgl::triangles3d(x = ray_base$verts, 
+                     indices = ray_base$inds, 
+                     texcoords = ray_base$texcoords, 
+                     color=basecolor,back="cull", front="filled",
+                     lit=FALSE,texture=NULL,tag = "basebottom")
+    
+    # rgl::surface3d(x=1:nrow(basemat)-1-(nr-1)/2,
+    #                z=1:ncol(basemat)-1-(nc-1)/2,
+    #                y=basemat,
+    #                color=basecolor, 
+    #                lit=FALSE,back="cull",front="filled",tag = "basebottom",
+    #                normal_x = xznormals, normal_z = xznormals, normal_y = ynormals)
     
   }
 }
