@@ -12,6 +12,9 @@
 make_water = function(heightmap,waterheight=mean(heightmap),watercolor="lightblue",zscale=1,wateralpha=0.5) {
   heightmap = heightmap/zscale
   na_matrix = is.na(heightmap)
+  nr = nrow(heightmap)
+  nc = ncol(heightmap)
+  
   waterheight = waterheight/zscale
   if(all(heightmap >= waterheight, na.rm=TRUE)) {
     warning("No water rendered--all elevations above or equal to water level. Range of heights: ",
@@ -21,39 +24,45 @@ make_water = function(heightmap,waterheight=mean(heightmap),watercolor="lightblu
     heightlist = make_water_cpp(heightmap, na_matrix, waterheight)
     if(length(heightlist) > 0) {
       fullsides = do.call(rbind,heightlist)
-      fullsides[,1] = (fullsides[,1] - nrow(heightmap)/2)
-      fullsides[,3] = -(fullsides[,3] + ncol(heightmap)/2 - 1)
-      fullsides = fullsides[nrow(fullsides):1,]
-    } 
+      fullsides[,3] = -fullsides[,3]
+      fullsides[,1] = fullsides[,1] - 1
+      fullsides[,3] = fullsides[,3]
+      
+      fullsides[,1] = fullsides[,1] - (nr-1)/2
+      fullsides[,3] = fullsides[,3] - (nc-1)/2
+    }
+    nr1 = nr-1
+    nc1 = nc-1
+    
     if(all(!na_matrix)) {
-      vertices = rbind(matrix(c(-nrow(heightmap)/2+1, nrow(heightmap)/2, -nrow(heightmap)/2+1,
+      vertices = rbind(matrix(c(-nr1/2,  nr1/2, -nr1/2,
                                 waterheight,waterheight,waterheight,
-                                ncol(heightmap)/2,-ncol(heightmap)/2+1,-ncol(heightmap)/2+1), 
+                                 nc1/2, -nc1/2, -nc1/2), 
                               nrow = 3L, ncol = 3L),
-                       matrix(c(-nrow(heightmap)/2+1, nrow(heightmap)/2, nrow(heightmap)/2,
+                       matrix(c(-nr1/2, nr1/2, nr1/2,
                                 waterheight,waterheight,waterheight,
-                                ncol(heightmap)/2,ncol(heightmap)/2,-ncol(heightmap)/2+1), 
+                                 nc1/2, nc1/2, -nc1/2), 
                               nrow = 3L, ncol = 3L))
-      indices = 1L:6L
+      indices = seq_len(6L)
       rgl::triangles3d(x = vertices,
                        indices = indices,
                        color=watercolor,alpha=wateralpha, lit = FALSE,
-                       front="filled",back="culled",texture=NULL,tag = "water")
+                       front="filled",back="cull",texture=NULL,tag = "water")
       if(length(heightlist) > 0) {
-        indices = 1L:nrow(fullsides)
+        indices = rev(seq_len(nrow(fullsides)))
         rgl::triangles3d(fullsides, indices = indices,
                          lit=FALSE,color=watercolor,alpha=wateralpha,
-                         front="fill",back="culled",depth_test="less",texture=NULL,tag = "water")
+                         front="filled",back="cull",depth_test="less",texture=NULL,tag = "water")
       }
     } else {
       if(length(heightlist) > 0) {
-        indices = 1L:nrow(fullsides)
+        indices = rev(seq_len(nrow(fullsides)))
         rgl::triangles3d(fullsides,indices = indices,
                          lit=FALSE,color=watercolor,alpha=wateralpha,front="fill",back="culled",
                          texture=NULL,tag = "water")
       }
       
-      basemat = matrix(waterheight,nrow(heightmap),ncol(heightmap))
+      basemat = matrix(waterheight,nr,nc)
       basemat[is.na(heightmap)] = NA
       ray_surface = generate_surface(basemat, zscale = 1)
       
