@@ -94,19 +94,18 @@
 #'                  n = 200, bins = 50,contour = TRUE) +
 #'  facet_wrap(clarity~.) +
 #'  scale_fill_viridis_c(option = "A")
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'plot_gg(ggdiamonds,multicore = TRUE,width=5,height=5,scale=250,windowsize=c(1400,866),
 #'        zoom = 0.55, phi = 30)
 #'render_snapshot()
 #'}
 #'#Change the camera angle and take a snapshot:
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'render_camera(zoom=0.5,theta=-30,phi=30)
 #'render_snapshot()
 #'}
 #'
 #'#Contours and other lines will automatically be ignored. Here is the volcano dataset:
-#'
 #'ggvolcano = volcano %>% 
 #'  reshape2::melt() %>%
 #'  ggplot() +
@@ -115,16 +114,17 @@
 #'  scale_x_continuous("X",expand = c(0,0)) +
 #'  scale_y_continuous("Y",expand = c(0,0)) +
 #'  scale_fill_gradientn("Z",colours = terrain.colors(10)) +
-#'  coord_fixed()
+#'  coord_fixed() + 
+#'  theme(legend.position = "none")
 #'ggvolcano
 #'
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'plot_gg(ggvolcano, multicore = TRUE, raytrace = TRUE, width = 7, height = 4, 
 #'        scale = 300, windowsize = c(1400, 866), zoom = 0.6, phi = 30, theta = 30)
 #'render_snapshot()
 #'}
 #'
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'#You can specify the color and height separately using the `ggobj_height()` argument.
 #'ggvolcano_surface = volcano %>%
 #'reshape2::melt() %>%
@@ -148,10 +148,10 @@
 #'  scale_color_continuous(limits=c(0,8)) 
 #'
 #'#Preview how the plot will look by setting `preview = TRUE`: We also adjust the angle of the light.
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'plot_gg(mtplot, width=3.5, sunangle=225, preview = TRUE)
 #'}
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'plot_gg(mtplot, width=3.5, multicore = TRUE, windowsize = c(1400,866), sunangle=225,
 #'        zoom = 0.60, phi = 30, theta = 45)
 #'render_snapshot()
@@ -165,7 +165,7 @@
 #'  scale_fill_gradient(low="pink", high="red")
 #'mtplot_density
 #'
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'plot_gg(mtplot_density, width = 4,zoom = 0.60, theta = -45, phi = 30, 
 #'        windowsize = c(1400,866))
 #'render_snapshot()
@@ -174,28 +174,28 @@
 #'mtplot_density_facet = mtplot_density + facet_wrap(~cyl) 
 #'
 #'#Preview this plot in 2D:
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'plot_gg(mtplot_density_facet, preview = TRUE)
 #'}
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'plot_gg(mtplot_density_facet, windowsize=c(1400,866),
 #'        zoom = 0.55, theta = -10, phi = 25)
 #'render_snapshot()
 #'}
 #'#That is a little cramped. Specifying a larger width will improve the readability of this plot.
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'plot_gg(mtplot_density_facet, width = 6, preview = TRUE)
 #'}
 #'
 #'#That's better. Let's plot it in 3D, and increase the scale.
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'plot_gg(mtplot_density_facet, width = 6, windowsize=c(1400,866),
 #'        zoom = 0.55, theta = -10, phi = 25, scale=300)
 #'render_snapshot()
 #'}
 #'
 #'#We can also render a flat version of the plot alongside (or above/below) the 3D version.
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'plot_gg(mtplot_density_facet, width = 6, windowsize=c(1400,866),
 #'        zoom = 0.65, theta = -25, phi = 35, scale=300, flat_plot_render=TRUE,
 #'        flat_direction = "x")
@@ -686,7 +686,7 @@ plot_gg = function(ggobj, ggobj_height = NULL, width = 3, height = 3,
       } else {
         mapcolor %>%
           add_shadow(raylayer,shadow_intensity) %>%
-          plot_map(keep_user_par = FALSE)
+          plot_map()
       }
     } else {
       raylayer = saved_shadow_matrix
@@ -699,7 +699,7 @@ plot_gg = function(ggobj, ggobj_height = NULL, width = 3, height = 3,
       } else {
         mapcolor %>%
           add_shadow(raylayer,shadow_intensity) %>%
-          plot_map(keep_user_par = FALSE)
+          plot_map()
       }
     }
   } else {
@@ -708,7 +708,7 @@ plot_gg = function(ggobj, ggobj_height = NULL, width = 3, height = 3,
               max_error = max_error, max_tri = max_tri, verbose = verbose, shadow = shadow, 
               shadowdepth=shadowdepth/scale, background = background, shadowcolor = shadowcolor, ...)
     } else {
-      plot_map(mapcolor, keep_user_par = FALSE)
+      plot_map(mapcolor)
     }
   }
   if(!preview && flat_plot_render) {
