@@ -10,7 +10,7 @@
 #'@param shift_vertical Default `0`. Amount to shift the viewpoint. 
 #'@export
 #'@examples
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'montereybay %>%
 #'  sphere_shade() %>%
 #'  plot_3d(montereybay,zscale = 50, water = TRUE, waterlinecolor="white")
@@ -18,14 +18,14 @@
 #'}
 #'
 #'#Shift the camera over and add a title
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'render_camera(theta = -45, phi = 45)
 #'render_snapshot(title_text = "Monterey Bay, CA",
 #'                title_bar_color = "grey50")
 #'}
 #'
 #'#Shift to an overhead view (and change the text/title bar color)
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'render_camera(theta = 0, phi = 89.9, zoom = 0.9)
 #'render_snapshot(title_text = "Monterey Bay, CA",
 #'                title_color = "white",
@@ -33,7 +33,7 @@
 #'}
 #'
 #'#Shift to an front view and add a vignette effect
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'render_camera(theta = -90, phi = 30,zoom = 0.8)
 #'render_snapshot(title_text = "Monterey Bay, CA",
 #'                title_color = "white",
@@ -42,7 +42,7 @@
 #'}
 #'
 #'#Change the field of view (fov) and make the title bar opaque.
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'render_camera(theta = -90, phi = 30,zoom = 0.5,fov = 130)
 #'render_snapshot(title_text = "Monterey Bay, CA",
 #'                title_color = "black",
@@ -53,7 +53,7 @@
 #'
 #'#Here we render a series of frames to later stitch together into a movie.
 #'
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'phivec = 20 + 70 * 1/(1 + exp(seq(-5, 10, length.out = 180)))
 #'phivecfull = c(phivec, rev(phivec))
 #'thetavec = 270 + 45 * sin(seq(0,359,length.out = 360) * pi/180)
@@ -102,6 +102,9 @@ render_camera = function(theta = NULL, phi = NULL, zoom = NULL, fov = NULL,
       } else {
         theta = rotmat[2]
       }
+      if(abs(phi) == 90) {
+        theta = theta - 90
+      }
     }
   }
   rgl::view3d(theta = theta, phi = phi, fov = fov, zoom = zoom)
