@@ -25,8 +25,6 @@
 #'@param instant_capture Default `TRUE` if interactive, `FALSE` otherwise. If `FALSE`, a slight delay is added 
 #'before taking the snapshot. This can help stop prevent rendering issues when running scripts.
 #'@param bring_to_front Default `FALSE`. Whether to bring the window to the front when taking the snapshot.
-#'@param keep_user_par Default `TRUE`. Whether to keep the user's `par()` settings. Set to `FALSE` if you 
-#'want to set up a multi-pane plot (e.g. set `par(mfrow)`).
 #'@param webshot Default `FALSE`. Set to `TRUE` to have rgl use the `webshot2` package to take images,
 #'which can be used when `rgl.useNULL = TRUE`.
 #'@param width Default `NULL`. Optional argument to pass to `rgl::snapshot3d()` to specify the
@@ -35,8 +33,9 @@
 #'height when `software_render = TRUE`.
 #'@param software_render Default `FALSE`. If `TRUE`, rayshader will use the rayvertex package to render the snapshot, which
 #'is not constrained by the screen size or requires OpenGL. 
-#'Consider settings a `cache_filename` so a new OBJ file doesn't have to be written with every snapshot.
-#'@param cache_filename Default `NULL`. Name of temporary filename to store OBJ file, if the user does not want to rewrite the file each time.
+#'@param cache_scene Default `FALSE`. Whether to cache the current scene to memory so it does not have to be converted to a `raymesh` object 
+#'each time `render_snapshot()` is called. If `TRUE` and a scene has been cached, it will be used when rendering.
+#'@param reset_scene_cache Default `FALSE`. Resets the scene cache before rendering.
 #'@param background Default `NULL`, defaults to device background. Background color when `software_render = TRUE`.
 #'@param text_angle Default `NULL`, which forces the text always to face the camera. If a single angle (degrees),
 #'will specify the absolute angle all the labels are facing. If three angles, this will specify all three orientations
@@ -67,18 +66,18 @@
 #'@return Displays snapshot of current rgl plot (or saves to disk).
 #'@export
 #'@examples
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'montereybay %>%
 #'  sphere_shade() %>%
 #'  plot_3d(montereybay,zscale=50,zoom=0.6,theta=-90,phi=30)
 #'}
 #'  
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'render_snapshot()
 #'}
 #'  
 #'#Create a title
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'render_snapshot(title_text = "Monterey Bay, California", title_offset=c(0,20),
 #'                title_color = "white", title_bar_color = "black",
 #'                title_font = "Helvetica", title_position = "north")
@@ -91,18 +90,18 @@
 #'                title_font = "Helvetica", title_position = "north")
 #'}
 #'#Use software rendering to render a scene with shadow mapping
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'montereybay |> 
 #'  height_shade() |> 
 #'  plot_3d(montereybay, shadow=FALSE, solidlinecolor = NULL)
 #'#No shadows
 #'render_snapshot(software_render = TRUE)
 #'}
-#'if(rayshader:::run_documentation()) {
+#'if(run_documentation()) {
 #'#Now with shadow mapped shadows, calculated in rayvertex
 #'render_snapshot(rayvertex_lighting = TRUE, 
-#'                rayvertex_lights = rayvertex::directional_light(intensity = 2.5, 
-#'                                                                direction = c(-1, 0.8, -1)), 
+#'                rayvertex_lights = rayvertex::directional_light(intensity = 1.2, 
+#'                                                                direction = c(-1, 1, -1)), 
 #'                rayvertex_shadow_map = TRUE, software_render = TRUE)
 #'}
 render_snapshot = function(filename, clear=FALSE, 
@@ -113,14 +112,14 @@ render_snapshot = function(filename, clear=FALSE,
                            image_overlay = NULL, 
                            vignette = FALSE, vignette_color = "black", vignette_radius = 1.3,
                            instant_capture = interactive(), bring_to_front = FALSE, 
-                           keep_user_par = FALSE, webshot = FALSE, 
+                           webshot = FALSE, 
                            width = NULL, height = NULL, 
                            software_render = FALSE, camera_location = NULL, camera_lookat = c(0,0,0),
                            background = NULL,
                            text_angle = NULL, text_size = 30, text_offset = c(0,0,0),
                            point_radius = 2, 
                            line_offset = 1e-7, thick_lines = TRUE, line_radius = 0.5,
-                           cache_filename  = NULL,  new_page = TRUE,
+                           cache_scene  = FALSE, reset_scene_cache = FALSE, new_page = TRUE,
                            print_scene_info = FALSE, fsaa = 1, 
                            rayvertex_lighting = FALSE, rayvertex_lights = NULL,
                            rayvertex_shadow_map = FALSE,
@@ -128,6 +127,9 @@ render_snapshot = function(filename, clear=FALSE,
   if(rgl::rgl.useNULL()) {
     software_render = TRUE
   }
+  if(reset_scene_cache) {
+    assign("scene_cache", NULL, envir = ray_cache_scene_envir)
+  }
   fsaa = as.integer(fsaa)
   stopifnot(fsaa >= 1)
   if(rgl::cur3d() == 0) {
@@ -176,7 +178,7 @@ render_snapshot = function(filename, clear=FALSE,
       background = rgl::rgl.attrib(bgid,"colors")
     }
     stopifnot(length(text_offset) == 3)
-    debug = render_snapshot_software(filename = temp, cache_filename = cache_filename,
+    debug = render_snapshot_software(filename = temp, cache_scene = cache_scene,
                              camera_location = camera_location, camera_lookat = camera_lookat,
                              background = background,
                              width = width, height = height, light_direction = NULL, fake_shadow = TRUE, 
@@ -205,7 +207,7 @@ render_snapshot = function(filename, clear=FALSE,
                                   title_size = title_size, title_font = title_font)
   }
   if(missing(filename)) {
-    rayimage::plot_image(tempmap, keep_user_par = keep_user_par, new_page = new_page)
+    rayimage::plot_image(tempmap, new_page = new_page)
   } else {
     save_png(tempmap, filename)
   }
